#ifndef _MEM_MEMORY
#define _MEM_MEMORY

#include <vector>
#include <cstdio>
#include <cstdlib>
#include "sdl.h"
#include "mem_carta.h"

class Memory : public sdl::Game, public sdl::Mixer {
private:
    sdl::Font font;                 /**< Fuente para puntuaciones */
    sdl::Music music;               /**< Música */
    int dificultad;                 /**< Nivel de dificultad */
    int nParejas;                   /**< Número de parejas, en función de la dificultad */
    int nColumnas;                  /**< Número de columnas, en función de la dificultad */
    int nFilas;                     /**< Número de filas, en función de la dificultad */
    sdl::TextureArray *graficos;    /**< Gráficos */
    std::vector<mem::Carta> baraja; /**< Conjunto de parejas de cartas */
    sdl::Point inicio;              /**< Coordenadas de primera carta */
    int estado=0;                   /**< Estado del bucle del juego */
    bool musica;                    /**< Indica si la música se debe reproducir */
    int carta1, carta2;             /**< Índices de las cartas levantadas por el jugador */
    int intentos;                   /**< Número de intentos, parejas levantadas */
    int aciertos;                   /**< Número de aciertos, parejas levantadas coincidentes */
    sdl::Button *boton;

public:
    Memory(sdl::Window& window, sdl::Renderer& renderer) : sdl::Game(window, renderer, 800, 600),
        sdl::Mixer(MIX_INIT_MID|MIX_INIT_OGG),
        font(renderer, "./fuentes/arialbd.ttf"),
        music("Brandenburg_Concerto_3.mid"),
        dificultad(0), musica(false), intentos(0), aciertos(0) {
        // Leer graficos
        graficos = new sdl::TextureArray(renderer, std::string("./graficos/cartas.png"), 48, 48);
        music.Play(0);
        if(!musica) music.Pause();
        boton = new sdl::Button(renderer, sdl::Point(10,520), graficos, 53, "Salir", font, 50, sdl::Color("#ffff00ff"));
        boton->SetVisible(true);
    }
    ~Memory() {
        delete graficos;
        delete boton;
    }
    void SetDificultad(int d) { dificultad = d; }
    int GetDificultad() { return dificultad; }
    void Init();
    void Events();
    void Update() {}
    void Render();
    char Run();
    bool SwitchMusica() { musica = !musica; if(musica) music.Resume(); else music.Pause(); return musica; }
    bool Musica() { return musica; }
    char Menu1(int s=-1);
    char Menu2(int s=-1);
};

class MemMenu : public sdl::Menu {
public:
    MemMenu(sdl::Window& win, sdl::Renderer& ren, const std::string& font) : sdl::Menu(win, ren, font) {}
    ~MemMenu() {}
    void Render();
};
#endif // MEM_MEMORY
