/*
 * Clases para manejar eventos en SDL2
 * SDL_PollEvent
 */
#ifndef _SDL_EVENT
#define _SDL_EVENT

#define EXPORT __declspec(dllexport)

#include <SDL.h>

namespace sdl {

/** \class Event
 *  \brief Clase para encapsular un evento SDL
 *
 */
class Event {
protected:
    SDL_Event event;    /**< Estructura encapsulada */

public:
    /** \brief Constructor
     *
     */
	EXPORT Event() { memset(static_cast<void*>(&event), 0, sizeof(SDL_Event)); }
    /** \brief Recupera un evento de la cola de eventos pendientes
     *
     * \return bool true si haba algn evento para recuperar
     *
     */
	EXPORT bool Poll() { return SDL_PollEvent(&event); }
    /** \brief Obtiene el tipo de evento
     *
     * \return Uint32 valor del tipo de evento
     *
     */
	EXPORT Uint32 Type() { return event.type; }
    /** \brief Operador de conversin de tipo, convierte un objeto Event a SDL_Event
     *
     * \return SDL_Event evento SDL retornado
     *
     */
	EXPORT operator SDL_Event&() { return event; }
    /** \brief Obtiene una refencia al objeto SDL_Keyboard asociado al evento
     *
     */
	EXPORT SDL_KeyboardEvent &Key() { return event.key; }
    /** \brief Obtiene una refencia al objeto SDL_MouseButtonEvent asociado al evento
     *
     */
	EXPORT SDL_MouseButtonEvent &Button() { return event.button; }
};

}; // namespace

#endif // _SDL_EVENT
