#include "sdl_hitbox.h"

namespace sdl {
EXPORT Shape Shape::Move(float alfa, FPoint &displacement, FPoint &escale) {
    FPoint point;

    if(type == circle) {
        point = ci.Center().Move(alfa, displacement, escale);
        return Shape(FCircle(point, ci.R()*escale.X()));
    }
    //rectangulo:
    point = re.Corner().Move(alfa, displacement, escale);
    return Shape(FRect(point.X(), point.Y(), re.W()*escale.X(), re.H()*escale.Y()));
}

EXPORT bool Hitbox::CollisionCircleCircle(FCircle &c1, FCircle &c2) {
    if(((c1.R()+c2.R())*(c1.R()+c2.R())) >=
       ((c1.Center().X()-c2.Center().X())*(c1.Center().X()-c2.Center().X())+
        (c1.Center().Y()-c2.Center().Y())*(c1.Center().Y()-c2.Center().Y())))
        return true;
    return false;
}

EXPORT bool Hitbox::CollisionRectRect(FRect &r1, FRect &r2) {
    return SDL_HasIntersectionF(r1.Get(), r2.Get());
}

EXPORT bool Hitbox::CollisionRectCircle(FRect &re, FCircle &ci) {
    FPoint pt = ci.Center();
    if(pt.X() < re.X()) pt.X() = re.X();
    if(pt.Y() < re.Y()) pt.Y() = re.Y();
    if(pt.X() > re.X()+re.W()) pt.X() = re.X()+re.W();
    if(pt.Y() > re.Y()+re.H()) pt.Y() = re.Y()+re.H();
    return ((pt.X()-ci.X())*(pt.X()-ci.X())+(pt.Y()-ci.Y())*(pt.Y()-ci.Y())) <= ci.R()*ci.R();
}

EXPORT bool Hitbox::Collision(Hitbox &hitbox2) {
    for(size_t i=0; i<hitboxT.size(); i++) {
        for(size_t j=0; j<hitbox2.hitboxT.size(); j++) {
            if(hitbox[i].type==circle && hitbox2.hitbox[j].type==circle) {
                return CollisionCircleCircle(hitboxT[i].ci, hitbox2.hitboxT[j].ci);
            } else
            if(hitbox[i].type==rectangle && hitbox2.hitbox[j].type==rectangle) {
                return CollisionRectRect(hitboxT[i].re, hitbox2.hitboxT[j].re);
            } else
            if(hitbox[i].type==rectangle) {
                return CollisionRectCircle(hitboxT[i].re, hitbox2.hitboxT[j].ci);
            } else
                return CollisionRectCircle(hitbox2.hitboxT[j].re, hitboxT[i].ci);
        }
    }
    return false;
}

EXPORT void Hitbox::Move(float alfa, FPoint &displacement, FPoint &escale) {
    for(size_t i = 0; i < hitbox.size(); i++) {
        hitboxT[i] = hitbox[i].Move(alfa, displacement, escale);
    }
}
}
