/*
 * Clases para manejar librera SDL2
 * Mix_Init
 * Mix_OpenAudio
 * Mix_CloseAudio
 * Mix_Quit
 */

#ifndef _SDL_MIXER
#define _SDL_MIXER

#define EXPORT __declspec(dllexport)

#include <SDL.h>
#include <SDL_mixer.h>
#include "sdl_music.h"
#include "sdl_chunk.h"

namespace sdl {

/** \class Mixer
 *  \brief Clase para manejar la librera del mezclador de sonido, SDL_mixer
 *
 */
class Mixer {
public:
    /** \brief Constructor
     *
     * Inicializa la librera SDL_mixer y abre el dispositivo de audio predeterminado para la reproduccin.
     *
     * \param flags int banderas de formato de audio: MIX_INIT_FLAC, MIX_INIT_MOD, MIX_INIT_MP3, MIX_INIT_OGG, MIX_INIT_MID, MIX_INIT_OPUS, MIX_INIT_WAVPACK
     * \param frequency int La frecuencia a la que se reproducir el audio (en Hz).
     * \param format Uint16 Formato de audio, uno de los valores AUDIO_* de SDL.
     * \param channels int Nmero de canales (1 es mono, 2 es estreo, etc.).
     * \param chunksize int Tamao del bfer de audio en FRAMES de muestra (muestras totales divididas por el recuento de canales).
     *
     */
    EXPORT Mixer(int flags=0, int frequency=44100, Uint16 format= MIX_DEFAULT_FORMAT, int channels=2, int chunksize=2048) {
        Mix_Init(flags);
        Mix_OpenAudio(frequency, format, channels, chunksize);
    }
    /** \brief Destructor
     *
     * Cierra el mezclador, deteniendo toda la reproduccin de audio y desinicializa SDL_mixer.
     *
     */
    EXPORT ~Mixer() {
        Mix_CloseAudio();
        Mix_Quit();
    }
    /** \brief Suspende o reanuda toda la salida de audio.
     *
     * \param on int 1 para pausar la salida de audio, o 0 para reanudarla.
     *
     */
    EXPORT void Pausa(int on) {
        Mix_PauseAudio(on);
    }
};

} // namespace

#endif // _SDL_MIXER
