/*
 * Clases para manejar librería SDL2
 * SDL_Init
 * SDL_Quit
 * TTF_Init
 * TTF_Quit
 */
#ifndef _SDL_SDL2
#define _SDL_SDL2

#define EXPORT __declspec(dllexport)

/** \brief
 * Espacio con nombre para el wrapper de SDL2.
 *
 */
namespace sdl {

/** \class SDL2
 *  \brief La clase SDL2 contiene los métodos y datos para iniciar y liberar
 * los recursos necesarios para utilizar las librerías SDL2.
 *
 */

class SDL2 {
protected:
    bool valid = true;      /**< Indica si las librerías han podido ser iniciadas correctamente.  */
    bool valid_ttf = true;  /**< Indica si la librería TTF ha podido ser iniciada correctamente.  */

public:
    /** \brief
     * Constructor.
     * \param flags Banderas de inicialización de la librería SDL2. El valor por defecto es SDL_INIT_EVERYTHING.
     * \param initTTF indica si se debe inicializar la librería TTF.
     *
     */
    EXPORT SDL2(Uint32 flags=SDL_INIT_EVERYTHING, bool initTTF=false) {
        valid = (SDL_Init(flags) == 0);
        if(valid && initTTF) {
            valid_ttf = !TTF_Init();
        }
    }
    /** \brief
     * Destructor.
     *
     */
    EXPORT ~SDL2() {
        if(valid) SDL_Quit();
        if(valid_ttf) TTF_Quit();
    }
};
} // namespace
#endif // _SDL_SDL2
