/*
 * Clases para manejar texturas en SDL2
 */
#ifndef _SDL_TEXTURE
#define _SDL_TEXTURE

#define EXPORT __declspec(dllexport)

#include <string>
#include <SDL.h>
#include <SDL_image.h>
#include "sdl_renderer.h"

namespace sdl {

/** \class Texture
 * \brief Clase que encapsula una nica textura
 *
 */
class Texture {
protected:
    Renderer& renderer;     /**< Referencia de contexto de renderizado */
    SDL_Texture *texture;   /**< Una estructura opaca que contiene una representacin eficiente y especfica del controlador de los datos de pxeles. */
    Rect rect;              /**< Rectngulo que contiene la anchura y altura de la textura */

public:
    /** \brief Constructor
     *
     * \param render Renderer& contexto de renderizado
     * \param file string ruta del fichero que contiene el grfico de la textura
     *
     */
    EXPORT Texture(Renderer& render, std::string file) : renderer(render) {
        texture = IMG_LoadTexture(renderer, file.c_str());
        rect = Rect(0,0);
        SDL_QueryTexture(texture, NULL, NULL, &rect.W(), &rect.H());
    }
    /** \brief Destructor
     *
     * Destruye la textura especificada.
     *
     */
    EXPORT ~Texture() {
        SDL_DestroyTexture(texture);
    }
    /** \brief Obtiene un puntero a la estructura SDL_Texture
     *
     */
    EXPORT SDL_Texture* Get() { return texture; }
    /** \brief Obtiene un puntero a la estructura SDL_Texture
     *
     */
    EXPORT operator SDL_Texture*() { return texture; }
    /** \brief Traslada la textura al punto indicado
     *
     * \param punto Point punto de destino
     *
     */
    EXPORT void Draw(Point punto) {
        rect.X() = punto.X();
        rect.Y() = punto.Y();
        SDL_SetRenderTarget(renderer, NULL);
        SDL_RenderCopy(renderer, texture, NULL, rect.Get());
    }
};

} // namespace

#endif // _SDL_TEXTURE
